==> agrosyst-cli-1.4.5-sources.jar: fr/inra/agrosyst/services/pz0import/practicedPlot/PracticedPlotImportDto.java <==
package fr.inra.agrosyst.services.pz0import.practicedPlot;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: PracticedPlotImportDto.java 4756 2015-02-04 15:23:40Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.5/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/practicedPlot/PracticedPlotImportDto.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.entities.practiced.PracticedPlotImpl;

/**
 * Created by davidcosse on 16/12/14.
 */
public class PracticedPlotImportDto extends PracticedPlotImpl {

    public static final String PROPERTY_ID = "id";
    public static final String PROPERTY_PRACTICED_SYSTEM_ID="practicedSystemId";
    public static final String PROPERTY_LOCATION_ID = "locationId";
    public static final String PROPERTY_SURFACE_TEXTURE_ID = "surfaceTextureId";
    public static final String PROPERTY_SOL_DEPTH_ID = "solDepthId";
    public static final String PROPERTY_SUB_SOIL_TEXTURE_ID = "subSoilTextureId";

    private String id;
    private String practicedSystemId;
    private String locationId;
    private String surfaceTextureId;
    private String subSoilTextureId;
    private String solDepthId;
    //enums
    private String waterFlowDistanceImportedValue;
    private String irrigationSystemTypeImportedValue;
    private String pompEngineTypeImportedValue;
    private String hosesPositionningImportedValue;
    private String frostProtectionTypeImportedValue;
    private String solWaterPhImportedValue;
    private String maxSlopeImportedValue;
    private String bufferStripImportedValue;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPracticedSystemId() {
        return practicedSystemId;
    }

    public void setPracticedSystemId(String practicedSystemId) {
        this.practicedSystemId = practicedSystemId;
    }

    public String getLocationId() {
        return locationId;
    }

    public void setLocationId(String locationId) {
        this.locationId = locationId;
    }

    public String getSurfaceTextureId() {
        return surfaceTextureId;
    }

    public void setSurfaceTextureId(String surfaceTextureId) {
        this.surfaceTextureId = surfaceTextureId;
    }

    public String getSubSoilTextureId() {
        return subSoilTextureId;
    }

    public void setSubSoilTextureId(String subSoilTextureId) {
        this.subSoilTextureId = subSoilTextureId;
    }

    public String getSolDepthId() {
        return solDepthId;
    }

    public void setSolDepthId(String solDepthId) {
        this.solDepthId = solDepthId;
    }

    public String getWaterFlowDistanceImportedValue() {
        return waterFlowDistanceImportedValue;
    }

    public void setWaterFlowDistanceImportedValue(String waterFlowDistanceImportedValue) {
        this.waterFlowDistanceImportedValue = waterFlowDistanceImportedValue;
    }

    public String getIrrigationSystemTypeImportedValue() {
        return irrigationSystemTypeImportedValue;
    }

    public void setIrrigationSystemTypeImportedValue(String irrigationSystemTypeImportedValue) {
        this.irrigationSystemTypeImportedValue = irrigationSystemTypeImportedValue;
    }

    public String getPompEngineTypeImportedValue() {
        return pompEngineTypeImportedValue;
    }

    public void setPompEngineTypeImportedValue(String pompEngineTypeImportedValue) {
        this.pompEngineTypeImportedValue = pompEngineTypeImportedValue;
    }

    public String getHosesPositionningImportedValue() {
        return hosesPositionningImportedValue;
    }

    public void setHosesPositionningImportedValue(String hosesPositionningImportedValue) {
        this.hosesPositionningImportedValue = hosesPositionningImportedValue;
    }

    public String getFrostProtectionTypeImportedValue() {
        return frostProtectionTypeImportedValue;
    }

    public void setFrostProtectionTypeImportedValue(String frostProtectionTypeImportedValue) {
        this.frostProtectionTypeImportedValue = frostProtectionTypeImportedValue;
    }

    public String getSolWaterPhImportedValue() {
        return solWaterPhImportedValue;
    }

    public void setSolWaterPhImportedValue(String solWaterPhImportedValue) {
        this.solWaterPhImportedValue = solWaterPhImportedValue;
    }

    public String getMaxSlopeImportedValue() {
        return maxSlopeImportedValue;
    }

    public void setMaxSlopeImportedValue(String maxSlopeImportedValue) {
        this.maxSlopeImportedValue = maxSlopeImportedValue;
    }

    public String getBufferStripImportedValue() {
        return bufferStripImportedValue;
    }

    public void setBufferStripImportedValue(String bufferStripImportedValue) {
        this.bufferStripImportedValue = bufferStripImportedValue;
    }
}

==> agrosyst-cli-1.4.6-sources.jar: fr/inra/agrosyst/services/pz0import/practicedPlot/PracticedPlotImportDto.java <==
package fr.inra.agrosyst.services.pz0import.practicedPlot;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: PracticedPlotImportDto.java 4756 2015-02-04 15:23:40Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/1.4.6/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/practicedPlot/PracticedPlotImportDto.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.entities.practiced.PracticedPlotImpl;

/**
 * Created by davidcosse on 16/12/14.
 */
public class PracticedPlotImportDto extends PracticedPlotImpl {

    public static final String PROPERTY_ID = "id";
    public static final String PROPERTY_PRACTICED_SYSTEM_ID="practicedSystemId";
    public static final String PROPERTY_LOCATION_ID = "locationId";
    public static final String PROPERTY_SURFACE_TEXTURE_ID = "surfaceTextureId";
    public static final String PROPERTY_SOL_DEPTH_ID = "solDepthId";
    public static final String PROPERTY_SUB_SOIL_TEXTURE_ID = "subSoilTextureId";

    private String id;
    private String practicedSystemId;
    private String locationId;
    private String surfaceTextureId;
    private String subSoilTextureId;
    private String solDepthId;
    //enums
    private String waterFlowDistanceImportedValue;
    private String irrigationSystemTypeImportedValue;
    private String pompEngineTypeImportedValue;
    private String hosesPositionningImportedValue;
    private String frostProtectionTypeImportedValue;
    private String solWaterPhImportedValue;
    private String maxSlopeImportedValue;
    private String bufferStripImportedValue;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPracticedSystemId() {
        return practicedSystemId;
    }

    public void setPracticedSystemId(String practicedSystemId) {
        this.practicedSystemId = practicedSystemId;
    }

    public String getLocationId() {
        return locationId;
    }

    public void setLocationId(String locationId) {
        this.locationId = locationId;
    }

    public String getSurfaceTextureId() {
        return surfaceTextureId;
    }

    public void setSurfaceTextureId(String surfaceTextureId) {
        this.surfaceTextureId = surfaceTextureId;
    }

    public String getSubSoilTextureId() {
        return subSoilTextureId;
    }

    public void setSubSoilTextureId(String subSoilTextureId) {
        this.subSoilTextureId = subSoilTextureId;
    }

    public String getSolDepthId() {
        return solDepthId;
    }

    public void setSolDepthId(String solDepthId) {
        this.solDepthId = solDepthId;
    }

    public String getWaterFlowDistanceImportedValue() {
        return waterFlowDistanceImportedValue;
    }

    public void setWaterFlowDistanceImportedValue(String waterFlowDistanceImportedValue) {
        this.waterFlowDistanceImportedValue = waterFlowDistanceImportedValue;
    }

    public String getIrrigationSystemTypeImportedValue() {
        return irrigationSystemTypeImportedValue;
    }

    public void setIrrigationSystemTypeImportedValue(String irrigationSystemTypeImportedValue) {
        this.irrigationSystemTypeImportedValue = irrigationSystemTypeImportedValue;
    }

    public String getPompEngineTypeImportedValue() {
        return pompEngineTypeImportedValue;
    }

    public void setPompEngineTypeImportedValue(String pompEngineTypeImportedValue) {
        this.pompEngineTypeImportedValue = pompEngineTypeImportedValue;
    }

    public String getHosesPositionningImportedValue() {
        return hosesPositionningImportedValue;
    }

    public void setHosesPositionningImportedValue(String hosesPositionningImportedValue) {
        this.hosesPositionningImportedValue = hosesPositionningImportedValue;
    }

    public String getFrostProtectionTypeImportedValue() {
        return frostProtectionTypeImportedValue;
    }

    public void setFrostProtectionTypeImportedValue(String frostProtectionTypeImportedValue) {
        this.frostProtectionTypeImportedValue = frostProtectionTypeImportedValue;
    }

    public String getSolWaterPhImportedValue() {
        return solWaterPhImportedValue;
    }

    public void setSolWaterPhImportedValue(String solWaterPhImportedValue) {
        this.solWaterPhImportedValue = solWaterPhImportedValue;
    }

    public String getMaxSlopeImportedValue() {
        return maxSlopeImportedValue;
    }

    public void setMaxSlopeImportedValue(String maxSlopeImportedValue) {
        this.maxSlopeImportedValue = maxSlopeImportedValue;
    }

    public String getBufferStripImportedValue() {
        return bufferStripImportedValue;
    }

    public void setBufferStripImportedValue(String bufferStripImportedValue) {
        this.bufferStripImportedValue = bufferStripImportedValue;
    }
}
